package com.xinxincaravan.caravan.vehicle.rest;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.github.wxiaoqi.security.auth.client.annotation.IgnoreClientToken;
import com.github.wxiaoqi.security.auth.client.config.UserAuthConfig;
import com.github.wxiaoqi.security.auth.common.util.jwt.IJWTInfo;
import com.github.wxiaoqi.security.auth.common.util.jwt.JWTHelper;
import com.github.wxiaoqi.security.common.context.BaseContextHandler;
import com.github.wxiaoqi.security.common.msg.auth.TokenForbiddenResponse;
import com.xinxincaravan.caravan.vehicle.biz.VehicleBiz;
import com.xinxincaravan.caravan.vehicle.common.BaseController;
import com.xinxincaravan.caravan.vehicle.common.CustomIllegalParamException;
import com.xinxincaravan.caravan.vehicle.common.RestResponse;
import com.xinxincaravan.caravan.vehicle.constant.ResCode.ResCode;
import com.xinxincaravan.caravan.vehicle.constant.VehicleBookRecordStatus;
import com.xinxincaravan.caravan.vehicle.entity.Vehicle;
import com.xinxincaravan.caravan.vehicle.entity.VehicleBookInfo;
import com.xinxincaravan.caravan.vehicle.vo.AddOrUpdateVehicleVo;
import com.xinxincaravan.caravan.vehicle.vo.PageDataVo;
import com.xinxincaravan.caravan.vehicle.vo.BookVehicleVo;
import com.xinxincaravan.caravan.vehicle.vo.VehiclePageQueryVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/vehicleInfo")
@Slf4j
@IgnoreClientToken
public class VehicleController extends BaseController<VehicleBiz> {


    @RequestMapping(value ="/{id}",method = RequestMethod.GET)
    public RestResponse<Vehicle> get(@PathVariable String id) {
        return RestResponse.data(baseBiz.get(id));
    }

    @RequestMapping(value ="",method = RequestMethod.POST)
    public RestResponse add(@RequestBody List<AddOrUpdateVehicleVo> addOrUpdateVehicleVoList)  throws Exception{
        return baseBiz.add(addOrUpdateVehicleVoList);
    }

    @RequestMapping(value ="",method = RequestMethod.PUT)
    public RestResponse update(@RequestBody List<AddOrUpdateVehicleVo> addOrUpdateVehicleVoList)  throws Exception{
        return baseBiz.update(addOrUpdateVehicleVoList);
    }

    @RequestMapping(value ="",method = RequestMethod.DELETE)
    public RestResponse discard(@RequestBody List<String> idList)  throws Exception{
        return baseBiz.discard(idList);
    }



    @RequestMapping(value ="/page",method = RequestMethod.GET)
    public RestResponse<PageDataVo<Vehicle>> getByPage(@RequestParam String vehiclePageQueryVoJson) throws Exception{
        VehiclePageQueryVo vehiclePageQueryVo = null;
        try {
             vehiclePageQueryVo = JSON.parseObject(vehiclePageQueryVoJson,VehiclePageQueryVo.class);
             return RestResponse.data(baseBiz.getByPage(vehiclePageQueryVo));
        } catch (JSONException ex) {
            return RestResponse.code(ResCode.INVALID_REST_REQ_PARAM.getCode());
        } catch (CustomIllegalParamException ex){
            return RestResponse.code(ResCode.INVALID_REST_REQ_PARAM.getCode());
        }
    }

    @RequestMapping(value ="/bookedInfo/{vehicleId}/{yearMonth}",method = RequestMethod.GET)
    public RestResponse<VehicleBookInfo> getBookedInfo(@PathVariable String vehicleId, @PathVariable String yearMonth) {
        return RestResponse.data(baseBiz.getByVehicleIdAndYearMonth(vehicleId,yearMonth));
    }

    /**
     * 申请预定车辆
     * @param bookVehicleVo
     * @return
     */
    @RequestMapping(value ="/book/4employee",method = RequestMethod.POST)
    public RestResponse<Integer> applyVehicle(@RequestBody BookVehicleVo bookVehicleVo){
//        Integer operatorId = Integer.parseInt(BaseContextHandler.getUserID());
        Integer operatorId = -1;
        return baseBiz.applyVehicle4Employee(operatorId,bookVehicleVo);
    }

    /**
     * 批准预定车辆预定
     * @param bookRecordId
     * @return
     */
    @RequestMapping(value ="/book/4employee/prove/{bookRecordId}",method = RequestMethod.PUT)
    public RestResponse<Integer> proveVehicleBooking(@PathVariable Long bookRecordId) throws Exception{
//        Integer operatorId = Integer.parseInt(BaseContextHandler.getUserID());
        Integer operatorId = -1;
        return baseBiz.reviewVehicleBooking(operatorId, bookRecordId, VehicleBookRecordStatus.APPROVE.getCode());
    }

    /**
     * 拒绝预定车辆申请
     * @param bookRecordId
     * @return
     */
    @RequestMapping(value ="/book/4employee/reject/{bookRecordId}",method = RequestMethod.PUT)
    public RestResponse<Integer> rejectVehicleBooking(@PathVariable Long bookRecordId) throws Exception{
//        Integer operatorId = Integer.parseInt(BaseContextHandler.getUserID());
        Integer operatorId = -1;
        return baseBiz.reviewVehicleBooking(operatorId, bookRecordId, VehicleBookRecordStatus.REJECTED.getCode());
    }

//    /**
//     * 车辆归还
//     * @param bookRecordId
//     * @return
//     */
//    @RequestMapping(value ="/book/4employee/return/{bookRecordId}",method = RequestMethod.PUT)
//    public RestResponse<Integer> returnVehicle(@PathVariable String bookRecordId){
//        //此处待加入获取当前操作用户id信息以及相关权限验证
//        Integer operator = -1;//测试用
//        return baseBiz.returnVehicle(operator, bookRecordId);
//
//    }


    /**
     * 取消车辆预订
     * @param bookRecordId
     * @return
     */
    @RequestMapping(value ="/unbook/4employee/{bookRecordId}",method = RequestMethod.DELETE)
    public RestResponse<Integer> unbookVehicle(@PathVariable Long bookRecordId) throws Exception{
        //此处待加入获取当前操作用户id信息以及相关权限验证
//        Integer operatorId = Integer.parseInt(BaseContextHandler.getUserID());
        Integer operatorId = -1;
        return baseBiz.unbookVehicle4Employee(operatorId,bookRecordId);
    }

}
